/**
 * Description: 过滤器
 */

import format from 'date-fns/format';
import validator from "validator";


/**
 * 日期格式化
 * @param value
 * @param formatStr
 * @returns {null}
 */
export const dateFormat = (value, formatStr = 'YYYY-MM-DD HH:mm:ss') => {
	if (value) {
		if (typeof value === 'string') {
			value = parseInt(value);
		}
		return format(value, formatStr)
	}
	return null;
}

/**
 * 小数转百分比
 * @param value
 * @returns {*}
 */
export const decimalToPercentage = (value) => {
	if (value == 0) {
		return 0;
	}
	let str = Number(value * 100).toFixed();
	str += "%";
	return str;
}

/**
 * 时长转时分秒
 * @param value 秒
 * @returns {*}
 */
export const timeLengthFormat = (value) => {
	let hour = 0;
	let min = 0;
	let second = 0;
	let timeLength = ''
	if (value) {
		if (value > 60) {   //是否大于零
			min = parseInt(value / 60);  //分钟
			second = value % 60;  //秒
			if (min > 60) {   //存在时
				hour = parseInt(min / 60);
				min = min % 60;
			}
		} else {
			second = value;
		}

		if (hour > 0) {
			timeLength = hour + "小时"
		}
		if (min > 0) {
			timeLength = timeLength + min + "分"
		}
		timeLength = timeLength + second + "秒";   //秒必须出现无论是否大于零
	}
	return timeLength;
}


/**
 * 转文件大小格式
 * @param value
 * @returns {*}
 */
export const fileSizeFormat = (size) => {
	const fileSizeByte = size;
	let fileSizeMsg = ''
	if (fileSizeByte <= 1024) {
		fileSizeMsg = fileSizeByte + 'B'
	} else if (fileSizeByte <= Math.pow(1024, 2)) {
		fileSizeMsg = (fileSizeByte / Math.pow(1024, 1)).toFixed(2) + 'KB'
	} else if (fileSizeByte <= Math.pow(1024, 3)) {
		fileSizeMsg = (fileSizeByte / Math.pow(1024, 2)).toFixed(2) + 'MB'
	} else if (fileSizeByte <= Math.pow(1024, 4)) {
		fileSizeMsg = (fileSizeByte / Math.pow(1024, 3)).toFixed(2) + 'GB'
	}
	return fileSizeMsg;
}

/**
 * 毫秒转秒
 * @param value
 * @returns {*}
 */
export const millisecondToSecond = (value) => {
	if (typeof value !== 'number' || value == 0) {
		return 0;
	}
	let str = Number(value / 1000).toFixed(2);
	return str;
}

/**
 * 电话号码马赛克
 * @param phone
 * @returns {*}
 */
export const mosaicPhone = (phone) => {
	if (phone && validator.isMobilePhone(phone, ['zh-CN'])) {
		return phone.replace(/(\d{3})(\d{4})(\d{4})/, "$1****$3");
	}
	return phone;
}

export const globalFilter = [
	{
		name: 'dateFormat',
		filter: dateFormat
	},
	{
		name: 'timeLengthFormat',
		filter: timeLengthFormat
	},
	{
		name: 'decimalToPercentage',
		filter: decimalToPercentage
	},
	{
		name: 'fileSizeFormat',
		filter: fileSizeFormat
	},
	{
		name: 'millisecondToSecond',
		filter: millisecondToSecond
	},
	{
		name: 'mosaicPhone',
		filter: mosaicPhone
	}
]
