/**
 * Description: 校验
 * Author: longyihuang
 * Date: 2021/2/26
 * Location: shenzhen
 * E-Mail: 475865662@qq.com
 */

export const verify = {
	// 手机号
	mobile(rule, value, callback){
		let myreg = /^[1][3,4,5,6,7,8,9][0-9]{9}$/;
		if(rule.required == true && (value === '' || value === null || value === undefined)){
			callback(new Error( rule.text ? rule.text  : '请输入' ));
		}else if (value && !myreg.test(value)) {
			callback(new Error('请输入正确的电话号码!'));
		} else {
			callback();
		}
	},
	// 手机号 或者 电话号码
	contactNumber(rule, value, callback){
		let regTel= /^(0[0-9]{2,3}\-)?([2-9][0-9]{6,7})+(\-[0-9]{1,4})?$|(^(13[0-9]|15[0|3|6|7|8|9]|18[8|9])\d{8}$)/; // 电话号码
		if (!regTel.test(value)) {
			callback(new Error('请输入正确的联系电话!'));
		} else {
			callback();
		}
	},
	// 特殊字符校验
	sign(rule, value, callback){
		let regEn = /[`~!@#$%^&*()_+<>?:"{},.\/;'[\]]/im;
		let regCn = /[·！#￥（——）：；“”‘、，|《。》？、【】[\]]/im;
		if(rule.required && (value === '' || value === null)){
			callback(new Error( rule.text ? rule.text  :'请输入' ));
		} else if( value && ( regEn.test(value) || regCn.test(value)) ){
			callback(new Error('不能包含特殊字符'));
		}else{
			callback();
		}
	},
	// 中文
	china(rule, value, callback){
		let reg = new RegExp('^[\x01-\x7f]*$')
		if(rule.required && (value === '' || value === null)){
			callback(new Error( rule.text ? rule.text  :'请输入' ));
		} else if(value && reg.test(value)) {
			callback(new Error('只能输入中文!'))
		} else {
			callback();
		}
	},
	// 非中文
	noChinese(rule, value, callback){
		let reg = new RegExp('^[\x01-\x7f]*$')
		if(rule.required && (value === '' || value === null)){
			callback(new Error( rule.text ? rule.text  :'请输入' ));
		} else if(value && !reg.test(value)) {
			callback(new Error('不能输入中文!'))
		} else {
			callback();
		}
	},
	// 数字
	numberRule(rule, value, callback){
		let reg = new RegExp('^[0-9]*$')
		if(rule.required==true && (value === '' || value === null)){
			callback(new Error( rule.text ? rule.text  : '请输入' ));
		}else if (value && !reg.test(value)) {
			callback(new Error('请输入0-9的数字!'))
		} else {
			callback();
		}
	},
	// 密码
	password(rule, value, callback){
		let reg = new RegExp('^[\x01-\x7f]*$')
		if(rule.required==true && (value === '' || value === null)){
			callback(new Error( rule.text ? rule.text  : '请输入' ));
		}else if (!reg.test(value)) {
			callback(new Error('请输入正确的密码!'));
		} else {
			callback();
		}
	},
}
